#
# spec file for package python-PyKMIP
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-PyKMIP
Version:        0.8.0
Release:        2.1
Summary:        KMIP v11 library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/OpenKMIP/PyKMIP
Source:         https://files.pythonhosted.org/packages/source/P/PyKMIP/PyKMIP-%{version}.tar.gz
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module testtools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-enum34
Requires:       python-SQLAlchemy
Requires:       python-cryptography
Requires:       python-requests
Requires:       python-six
%ifpython2
Requires:       python-enum34
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%python_subpackages

%description
PyKMIP is a Python implementation of the Key Management Interoperability
Protocol (KMIP). KMIP is a client/server communication protocol for the
storage and maintenance of key, certificate, and secret objects. The standard
is governed by the `Organization for the Advancement of Structured Information
Standards`_ (OASIS). PyKMIP supports a subset of features in versions
1.0 - 1.2 of the KMIP specification.

%prep
%setup -q -n PyKMIP-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pykmip-server
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec %{_bindir}/py.test kmip/tests/unit

%post
%python_install_alternative pykmip-server

%postun
%python_uninstall_alternative pykmip-server

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*
%python_alternative %{_bindir}/pykmip-server

%changelog
* Sun Jan  6 2019 dmueller@suse.com
- update to 0.8.0:
  * Add Sphinx-based client and server library documentation
  * Add server support for third-party authentication systems
  * Add client support for the Check operation
  * Add client support for the Rekey operation
  * Add client support for attestation credentials
  * Add a functional test suite for server authentication and access control
  * Add payloads for the Archive, Cancel, and GetUsageAllocation operations
  * Add payloads for the ObtainLease, Poll, and Recover operations
  * Update the server to support group-based operation policies
  * Update the server to support live loading of operation policy files
  * Update the server to support custom backend database file paths
  * Update the server to raise PermissionDenied on access control violations
  * Update the client to support custom configuration file paths
  * Update the ProxyKmipClient to support custom names for the Register operation
  * Update the ProxyKmipClient to set cryptographic usage masks for Derived keys
  * Update the README to reference the new documentation
  * Update the Travis CI configuration to include building the documentation
  * Update the Travis CI configuration to run integration and functional tests
  * Remove support for Python 3.3
  * Fix a denial-of-service bug by setting the server socket timeout
  * Fix a ProxyKmipClient bug with generic cryptographic parameter handling
  * Fix a ProxyKmipClient bug with cryptographic usage mask processing
* Thu Feb 15 2018 tbechtold@suse.com
- update to 0.7.0:
  * Add support for Python 3.6
  * Add support for the InitialDate attribute
  * Add server support for the GetAttributeList operation
  * Add server support for the Locate operation
  * Add client and server support for the MAC operation
  * Add client and server support for the Revoke operation
  * Add client and server support for the Encrypt operation
  * Add client and server support for the Decrypt operation
  * Add client and server support for the DeriveKey operation
  * Add client and server support for the Sign operation
  * Add client and server support for the SignatureVerify operation
  * Add client and server support for retrieving wrapped keys
  * Add client and server support for storing wrapped keys
  * Add KMIP 1.4 enumerations
  * Add server config option enabling certificate extension checks
  * Add server config option defining set of usable TLS ciphers
  * Add server config option setting the server log level
  * Update the server to enforce checking object state and usage masks
  * Update server Locate support to allow object name filtering
  * Remove support for Python 2.6
  * Fix bug with multithreading support with the SQLite backend
  * Fix bug with how open() is mocked in the server test suite
  * Fix bug with mismapped polymorphic identity for certificate objects
  * Fix bug with socket interrupt handling under Python 3.5
  * Fix bug with detached instance errors in the server test suite
- Use pytest for testing. That's what upstream does
- Use fdupes
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.6.0:
  * Add support for Python 3.5
  * Add support for the State and OperationPolicyName attributes
  * Add server support for the Activate and GetAttributes operations
  * Add server support for certificate-based client authentication
  * Add server support for object access control via operation policies
  * Add server support for loading of user-defined operation policies
  * Add client support for the GetAttributes operation
  * Update clients to support operation policy names with objects
  * Update ProxyKmipClient to support names when creating new objects
  * Remove coveralls integration
  * Fix bug with early server termination on missing request credential
  * Fix bug with closing the client while unconnected to a server
  * Fix bug with default values overriding server config file settings
  * Fix bug with early server termination on bad client certificates
  * Fix bug with deprecated usage of the bandit config file
  * Fix bug with ProxyKmipClient registering unset object attributes
- convert to singlespec
* Tue May 24 2016 slunkad@suse.com, johannes.grassler@suse.com
- Initial Packaging (version 0.5.0)
